# import pandas as pd, numpy as np
# import metrics
# import yaml

# with open('../data/config.yaml','r') as file:
#     config = yaml.safe_load(file)

# #531
# W531 = '531'
# primary531 = ['S00','P10.0','P01.00','H00.0']
# class W531:
#     def __init__(self,week,movement):
#         self.movement = movement
#         self.week = int(week)
#         with open('../data/programs/531.yaml','r') as file:
#             self.config = yaml.safe_load(file)
#         self.TM = config['training_max']

#     def give_numbers(self,week,movement):
#         return [self.TM[movement]*i/100 for i in self.config[movement][week-1]]

# # PPL2.0
# PPL2 = 'PPL 2.0'
# H = ['H00.0','H01.0','H30.1'] #deadlift, romanian deadlift, zercher goodmorning
# P = ['P01.00','P10.0','P20'] #bench press, military press, dips
# T = ['T11.1','T00','T23.1'] #row, chin up, karwoski row
# S = ['S00','S10','S31'] # squat, front squat, bulgarian split squat
# primaryPPL2 = [H,P,T,S]
# accessory = ['X','C','U','S','T','P','L']

# # monolith
# mon = 'monolith'
# with open('../data/programs/monolith.yaml','r') as file:
#     monolith = yaml.safe_load(file)
# class Monolith:
#     def __init__(self,week,L):
#         self.name = L
#         self.week = int(week)
#         self.number = int(week)*{'A':1,'B':2,'C':3}[L]
#         self.raw = {k : v[self.week-1] for k,v in monolith[L].items()}
#         self.sets = metrics.import_data()[0]
#         self.exercises = metrics.import_data()[1]
#         self.IDex = {k:v for k,v in zip(list(self.exercises['ID']),list(self.exercises['Exercise']))}
#         self.selX = [k for k,v in self.raw.items()]
#         self.TM = config['training_max']
#         self.todo = [{self.IDex[i] : [round(x/100*self.TM[i]) for x in self.raw[i]] for i in self.raw.keys() if type(self.raw[i]) == list},
#                      {self.IDex[i] : self.raw[i] for i in self.raw.keys() if type(self.raw[i]) != list}]

#     def __repr__(self):
#         string = ''
#         for i in self.raw.keys():
#             if type(self.raw[i]) == list:
#                 string += f'{self.IDex[i]} : {[round(x/100 * self.TM[i]) for x in self.raw[i]]}\n'
#             else: string += f'{self.IDex[i]} : {self.raw[i]}\n'
#         return string

#     def show_todo(self,summary):
#         todo = {}
#         for x in self.todo[1].keys():
#             try: done = sum(list(summary[summary['Exercise Name'] == x]['Reps']))
#             except KeyError: done = 0
#             todo[x] = int(self.todo[1][x] - done)
#         return todo

# ###################################################
# choice = [mon,W531,PPL2]
# default = mon



import pandas as pd, numpy as np
import bv_utils
import datetime

def sel_1RM_finder(d,start=0,end='end',e=1):
    sets = bv_utils.import_data()[0]
    if end=='end':end=len(sets)
    k = (datetime.datetime.now()-datetime.timedelta(days = d)).timestamp()
    while end-start>e:
        m = round((start+end)/2)
        if np.array(sets['Timestamp'])[m] >k: end = m
        else: start = m
    selsets = sets.loc[m:,:]
    dic = {k:0 for k in sets['ID']}
    for x in dic.keys():
        ex_list = list(selsets[selsets['ID'] == x]['Pred1RM'])
        if ex_list:
            dic[x] = round(max(ex_list))
    return dic


# last week

# objectives

# most done (by weight, numebr)



import numpy as np, pandas as pd, math, datetime
import yaml, os

class Biovector:

    ROOT_DIR = os.path.dirname(os.path.dirname(__file__))
    CONFIG =  os.path.join(ROOT_DIR,'config.yaml')
    with open(CONFIG) as f:
        config = yaml.load(f, Loader=yaml.FullLoader)

    def __init__(self,droplist=[],selected='all'):
        if selected == 'all': selected = list(self.config['paths'].keys())
        for d,p in self.config['paths'].items():
            if (d not in droplist) & (d in selected):
                self.__dict__[d] = pd.read_csv(os.path.join(self.ROOT_DIR,p))

    def export(self,data):
        """Export specific or all available data."""
        if data == 'all':
            for d in self.config['paths']:
                if d in self.__dict__.keys():
                    self.export(d)
        if data in self.config['paths'].keys():
            self.__dict__[data].to_csv(os.path.join(self.ROOT_DIR,self.config['paths'][data]), index=False)

    def input_weight(self,string):
        """Input new weight."""
        W = {k:list(self.weight[k]) for k in self.weight.columns}
        try:
            weight = float(string)
            print('weight is ok')
            W['Date'].append(str(datetime.datetime.now())[:-7])
            W['Time'].append(datetime.datetime.now().timestamp())
            W['Weight'].append(weight)
            self.weight = pd.concat((self.weight,pd.DataFrame(W)),ignore_index=True)
            self.export('weight')
        except ValueError: print("That's no moon!!")

    def list_exercises(self,t):
        """List exercises, optionally by category."""
        print('ID, Short, Exercise')
        for i in range(len(self.exercises)):
            if t in self.exercises.loc[i,'ID']:
                print(self.exercises.loc[i,'ID'],'  ',self.exercises.loc[i,'Short'],'  ',self.exercises.loc[i,'Exercise'])


##########################################################################
#DATA MANAGMENT
########################################################################
#TO REMOVE ??
# def import_data():
#     sets = pd.read_csv('../data/sets.csv')
#     exercises = pd.read_csv('../data/exercises.csv')
#     weight = pd.read_csv('../data/measures/weight.csv')
#     workouts = pd.read_csv('../data/stats/workouts.csv')
#     return(sets,exercises,weight,workouts)

# def export_data(S=None,X=None,W=None,K=None):
#     if isinstance(S,pd.DataFrame): S.to_csv('../data/sets.csv',index=False)
#     if isinstance(X,pd.DataFrame): X.to_csv('../data/exercises.csv',index=False)
#     if isinstance(W,pd.DataFrame): W.to_csv('../data/measures/weight.csv',index=False)
#     if isinstance(K,pd.DataFrame): K.to_csv('../data/stats/workouts.csv',index=False)

#################################################################################
## CSV UPDATE
##############################################################################
class Updater(Biovector):

    def __init__(self,**kwargs):
        super().__init__(**kwargs)

    def update_all(self):
        timer_start = datetime.datetime.now().timestamp()
        print('Calculating predicted 1RM...')
        self.update_1RM()
        print('Updating bodyweight...')
        self.update_BW()
        print('Calculating workloads...')
        self.update_load()
        print('Calculating predicted 1RL...')
        self.update_1RL()
        print('Determining reference 1RM/1RL...')
        self.find_1RL_1RM()
        print('Calulating set intensities...')
        self.update_intensity()
        print('Calculating set values...')
        self.update_h()
        print('Calculating hard set workload...')
        self.update_phi()
        print('Exporting updated data...')
        self.export('all')
        print(f'Update took {datetime.datetime.now().timestamp() - timer_start} seconds.')


    def update_1RM(self):
        """Update 1RM in sets."""
        self.sets['Pred1RM'] = np.around(epley(self.sets['Weight'], self.sets['Reps']))

    # Body weight
    def update_BW(self):
        """Estimate weight based on data in weight.csv."""
        interpolation = np.interp(self.sets['Timestamp'], self.weight['Time'], self.weight['Weight'])
        self.sets['User Weight'] = np.around(interpolation,1)

    # Load
    # Might change (exercise) to ID
    def update_load(self):
        """Update loads."""
        #if end == 'end': end = len(self.sets)
        deltadic = {k:v for k,v in zip(self.exercises['ID'].values,self.exercises['Delta'].values)}
        thetadic = {k:v for k,v in zip(self.exercises['ID'].values,self.exercises['theta'].values)}
        rhodic   = {k:v for k,v in zip(self.exercises['ID'].values,self.exercises['rho'].values)}
        deltas = np.array([i if i else 0 for i in [deltadic.get(i) for i in self.sets['ID']]])
        thetas = np.array([i if i else 0 for i in [thetadic.get(i) for i in self.sets['ID']]])
        rhos   = np.array([i if i else 0 for i in [rhodic.get(i) for i in self.sets['ID']]])
        weights      = self.sets['Weight'].values
        reps         = self.sets['Reps'].values
        user_weights = self.sets['User Weight'].values
        self.sets['Load'] = np.around((weights*deltas + user_weights*rhos*thetas) * reps)
        # for i in range(len(self.exercises)):
        #     Delta = self.exercises.loc[i,'Delta']
        #     kappa = self.exercises.loc[i,'theta']*self.exercises.loc[i,'rho']
        #     for s in range(start,end):
        #         if self.sets.loc[s,'Exercise Name'] == self.exercises.loc[i,'Exercise']:
        #             self.sets.loc[s,'Load'] = (self.sets.loc[s,'Weight']*Delta + self.sets.loc[s,'User Weight']*kappa) * self.sets.loc[s,'Reps']

    def update_1RL(self):
        """Update 1RL."""
        # if end == 'end': end = len(self.sets)
        # for i in range(start,end):
        #     self.sets.loc[i,'Pred1RL'] = epley(self.sets.loc[i,'Load']/self.sets.loc[i,'Reps'],self.sets.loc[i,'Reps'])
        self.sets['Pred1RL'] = np.around(epley(self.sets['Load']/self.sets['Reps'],self.sets['Reps']))

    # find recent 1RL and 1RM #here
    def find_1RL_1RM(self):
        """Find current 1RL 1RM."""
        # if end == 'end': end = len(self.sets)
        # for x in set(self.sets['Exercise Name']):
        #     df = self.sets[self.sets['Exercise Name'] == x]
        #     for i in range(start,end):
        #         if self.sets.loc[i,'Exercise Name'] == x:
        #             self.sets.loc[i,'1RL'] = np.array(df.loc[:i,'Pred1RL']).max()
        #             self.sets.loc[i,'1RM'] = np.array(df.loc[:i,'Pred1RM']).max()
        all_exercises = set(self.sets['Exercise Name'])
        for write,read in [('1RL','Pred1RL'),('1RM','Pred1RM')]:
            dic = {x : pd.Series(self.sets[self.sets['Exercise Name']==x][read].values,index=self.sets[self.sets['Exercise Name']==x].index) for x in all_exercises}
            for x,d in dic.items():
                dic[x] = pd.Series([d.values[0]] +[max(d.values[:i]) for i in range(1,len(d))],index=d.index)
            a = pd.concat([v for k,v in dic.items()]).sort_index()
            self.sets.loc[a.index, write] = np.around(a.values)

    def update_intensity(self):
        """Update intensity."""
        self.sets.loc[:,'Int'] = np.around(self.sets.loc[:,'Pred1RL']/self.sets.loc[:,'1RL'],2)

    def update_h(self):
        """Update set hardness."""
        self.sets.loc[:,'h'] = np.around(logistic(self.sets.loc[:,'Int']),2)

    def update_phi(self):
        """Update volume of hard sets."""
        self.sets.loc[:,'phi'] = np.around(self.sets.loc[:,'Load'] * self.sets.loc[:,'h'])


###############################################

##########################################################
def logistic(x):
    """Return hard set index when inputed proportion."""
    return 1.05/(1+math.e**(-40*(x-0.75)))

def epley(weight,reps):
    """Estimate 1RM."""
    return weight*(1+ reps/30)


def translate(strg):
    """Return (exercise,weight,reps,note,status) inferred from user input."""
    if '@' in strg:
        try: return (None,None,None,strg.split('@')[-1],'template')
        except: return (None,None,None,None,'template')
    # $
    if '$' in strg: return (None,None,None,None,'todo')
    # redo
    if '!' in strg:
        try: note = int(strg.split('!')[0])
        except: note = 1
        return (None,None,None,note,'redo')
    # delete
    if 'delete' in strg:
        try: note = strg.split('delete')[1]
        except: note = 1
        return (None,None,None,note,'delete')
    # help
    if 'help' in strg:
        try: note = strg.split('help')[1]
        except: note = None
        return (None,None,None,note,'help')
    # quit
    if 'quit' in strg: return (None,None,None,None,'end') # help
    # set
    s = strg.split(' ')
    if len(s) == 3:
        try: return (s[0],float(s[1]),int(s[2]),None,'active')
        except: pass
    if len(s) == 2:
        try: return (None,float(s[0]),int(s[1]),None,'active')
        except: pass
        try: return (s[0],None,int(s[1]),None,'active')
        except: pass
    if len(s) == 1:
        if s[0].isdigit(): return (None,None,int(s[0]),None,'active')
        else: return (s[0],None,None,None,'active')
    return(None,None,None,None,None)


# if __name__ == '__main__':
#     update_all()
    #S,*trash = import_data()
    #print('Weird K rebuild') #to remove
    #update_K(S,st1=0,st2=0) #to remove



import argparse, sys
import bv_utils,stats,workout,interactive


class Main():
    """Main object, redirects user inputs into different modules and functions."""

    def __init__(self):
        self.info = '\n'.join(f"   {k:<15}   {str(v.__doc__)}" for k,v in Main.__dict__.items() if k[0]!='_')
        parser = argparse.ArgumentParser(prog=('biovector'),
                                         description='biovector',
                                         usage=f'''bv <command> [<args>]

{self.info}
                             ''')
        parser.add_argument('command', help='Subcommand to run')
        args = parser.parse_args(sys.argv[1:2])
        #if not hasattr(self, args.command):
        #    print('Unrecognized command')
        #    parser.print_help()
            #exit(1)
        # use dispatch pattern to invoke method with same name
        getattr(self, args.command)()

    def sets(self):
        """Show, modify or add sets."""
        parser = argparse.ArgumentParser(description=self.sets.__doc__)
        subparsers = parser.add_subparsers(dest='sets')

        add_parser = subparsers.add_parser('add')
        add_parser.add_argument('sets',nargs='+')

        ls_parser = subparsers.add_parser('ls')
        ls_parser.add_argument('--verbose','-v',action='count')

        mod_parser = subparsers.add_parser('mod')
        mod_parser.add_argument('mod')

        del_parser = subparsers.add_parser('del')
        del_parser.add_argument('del')

        args = parser.parse_args(sys.argv[2:])
        print(args)
        # option -0 don't count
        # destination

    def workout(self):
        """Initialize new workout, visualize current workouts."""
        parser = argparse.ArgumentParser(description=self.workout.__doc__)
        subparsers = parser.add_subparsers(dest='workout')

        ls_parser = subparsers.add_parser('ls')

        new_parser = subparsers.add_parser('new')
        new_parser.add_argument('new')

        args = parser.parse_args(sys.argv[2:])
        print(args)

    def measures(self):
        """View or modify measures."""
        parser = argparse.ArgumentParser(description=self.measures.__doc__)
        subparsers = parser.add_subparsers(dest='measures')

        measures_parser = subparsers.add_parser('add')
        measures_parser = subparsers.add_parser('ls')
        # option bw neck etc
        args = parser.parse_args(sys.argv[2:])
        print(args)

    def program(self):
        """Interact with programs."""
        parser = argparse.ArgumentParser(description=self.program.__doc__)
        subparsers = parser.add_subparsers(dest='program')

        program_parser = subparsers.add_parser()
        program_parser.add_argument('show')

        program_parser.add_argument('ls')

        program_parser.add_argument('create')
        args = parser.parse_args(sys.argv[2:])
        print(args)

    def exercise(self):
        """Create or see last sets for a specific exercise."""
        parser = argparse.ArgumentParser(description=self.exercise.__doc__)
        subparsers = parser.add_subparsers(dest='exercise')

        program_parser = subparsers.add_parser()
        program_parser.add_argument('show')

        program_parser.add_argument('ls')

        program_parser.add_argument('create')
        args = parser.parse_args(sys.argv[2:])
        print(args)

    def interactive(self):
        """Interactive CLI mode."""
        interactive.main()

    def config(self):
        """Modify user configuration."""
        parser = argparse.ArgumentParser(description=self.config.__doc__)
        parser.add_argument('--thing')
        #TM, current program
        args = parser.parse_args(sys.argv[2:])
        print(args)

    def update(self):
        """Recalculate values."""
        parser = argparse.ArgumentParser(description=self.update.__doc__)
        #update all, update specific
        parser.add_argument('--all', '-a',action='store_true')
        args = parser.parse_args(sys.argv[2:])
        print(args)
        if args.all:
            bv_utils.Updater().update_all()

    def stats(self):
        """Show statistics."""
        parser = argparse.ArgumentParser(description=self.stats.__doc__)
        #1rm weekly yearly
        parser.add_argument('--rm')
        args = parser.parse_args(sys.argv[2:])
        print(args)


if __name__ == '__main__':
    m = Main()

#FILES
# main data : exercises,setss
# measures : bodyweight + the rest
# program instances
# status (current workout, current program, current exercise , current weight)

# SCRIPTS
# __main__, workout, interactive, stats, bv_utils, programs



import os, sys, numpy as np, pandas as pd, datetime
import stats, bv_utils, printbv
from bv_utils import Biovector


#######################################################################################

class Exercise(Biovector):
    def __init__(self,ID):
        super().__init__(droplist=['weight','workouts'])
        self.ID = ID
        self.exercise_history = self.sets[self.sets['ID'] == ID] #set history
        self.exercise_data = self.exercises[self.exercises['ID'] == ID] #exercise data
        self.name = list(self.exercise_data['Exercise'])[0]
        self.Delta = list(self.exercise_data['Delta'])[0]
        self.kappa = list(self.exercise_data['rho'])[0] * list(self.exercise_data['theta'])[0]
        self.Short = list(self.exercise_data['Short'])[0]
        self.est1RM = max(list(self.exercise_history['Pred1RM'])+[0])
        self.est1RL = max(list(self.exercise_history['Pred1RL'])+[0])

#######################################################################################

class Workout(Biovector):
    def __init__(self,name,program=None,t=0):
        super().__init__()
        self.name = name
        if program in 'c': self.program = 'à changer'
        if program == 'w': self.program = 'workout'
        if program == 'f': self.program = 'free'
        if self.program == 'fileadd':
            self.startingtime == t
        else:
            self.startingtime = datetime.datetime.now()
        self.start = self.startingtime.strftime("%Y-%m-%d %H:%M:%S")
        self.summary = pd.DataFrame({i:[] for i in list(self.sets.columns)})
        self.BW = self.weight.loc[len(self.weight)-1,'Weight']
        if self.program == 'free':
            self.number = 0
        else:
            self.number = int(max(list(self.sets.loc[:,'Number'])) + 1)
        self.exercise = None
        self.weight = None
        self.status = 'active'
        self.template = None

    def take_input(self, user_input):
        exercise, weight, reps, note, status = bv_utils.translate(user_input)
        if status: self.status = status #if status='end' it quits
        #possibilities
        if self.status == 'active':
            copy = self.exercise
            if exercise: self.choose_exercise(exercise)
            if self.exercise != copy: self.weight = None
            if weight or weight==0: self.weight = float(weight)
            if self.weight == None: self.weight = 0
            if reps and self.exercise and (self.weight or self.weight == 0):
                self.add_set(self.weight,int(reps),note)
            self.print_summary()
        if self.status == 'help':
            bv_utils.list_exercises(note)
        if self.status == 'delete':
            self.delete_set(note) ; self.status == None
        if self.status == 'template':
            try: self.program_print(note[0],note[1])
            except: pass
            try: self.program_print(self.week,self.L)
            except: pass
        if self.status == 'todo':
            print(self.template.show_todo(self.summary))
        if self.status == 'redo':
            self.redo(note)
            self.print_summary()

    def save(self,strg):
        if strg != 'n':
            self.export('sets')
            # bv_utils.export_data(S=self.sets)
        if self.number != 0:
            df = pd.DataFrame({'Number':    [self.number],
                               'Timestamp': [self.startingtime.timestamp()],
                               'Date':      [self.startingtime],
                               'Hardsets':  [sum(list(self.summary.loc[:,'h']))],
                               'Load':      [sum(list(self.summary.loc[:,'Load']))],
                               'Hardload':  [sum(list(self.summary.loc[:,'phi']))]})
            self.workouts = pd.concat((self.workouts,df),ignore_index=True)
            # bv_utils.export_data(K=self.workouts)
            self.export('workouts')

    def delete_set(self,n=1):
        try: n = int(n)
        except: n = 1
        if len(self.summary) < n:
            print("You're trying to delete previous sets!\n")
        else:
            self.sets = self.sets.iloc[:-n,:]
            self.summary = self.summary.iloc[:-n,:]
            self.exercise = Exercise(self.exercise.ID)

    def print_summary(self):
        printbv.print_summary(self.summary)

    def choose_exercise(self,name):
        if name in list(self.exercises['ID']):
            self.exercise = Exercise(name)
        if name in list(self.exercises['Short']):
            index = self.exercises[self.exercises['Short'] == name].index.tolist()[0]
            self.exercise = Exercise(self.exercises.loc[index,'ID'])
        if name in list(self.exercises['Exercise']):
            index = self.exercises[self.exercises['Exercise'] == name].index.tolist()[0]
            self.exercise = Exercise(self.exercises.loc[index,'ID'])

    def redo(self,note):
        delay = 0
        try: to_add = self.summary.loc[len(self.summary)-note:]
        except: print('out of range')
        for i in range(len(to_add)):
            self.exercise = Exercise(list(to_add['ID'])[i])
            weight = list(to_add['Weight'])[i]
            reps = list(to_add['Reps'])[i]
            self.add_set(weight,reps,'',delay)
            delay += 5

    def add_set(self, weight,reps,note,delay=0):
        set_dic = {i:[] for i in list(self.sets.columns)}
        load = round((self.exercise.Delta*weight+self.BW*self.exercise.kappa)*reps)
        if self.exercise.est1RL:
            intensity = round(bv_utils.epley(load/reps,reps) / self.exercise.est1RL,2)
        else: intensity = 1
        h = round(bv_utils.logistic(intensity),2)
        if self.program =='fileadd':
            set_dic['Timestamp'].append(self.startingtime+delay)
        else:
            set_dic['Timestamp'].append(datetime.datetime.now().timestamp()+delay)
        set_dic['Time'].append(self.start)
        set_dic['Number'].append(self.number)
        set_dic['Workout Name'].append(self.name)
        set_dic['Program'].append(self.program)
        set_dic['ID'].append(self.exercise.ID)
        set_dic['Exercise Name'].append(self.exercise.name)
        set_dic['Weight'].append(weight)
        set_dic['Reps'].append(reps)
        set_dic['User Weight'].append(self.BW)
        set_dic['Pred1RL'].append(round(bv_utils.epley(load/reps,reps)))
        set_dic['1RL'].append(self.exercise.est1RL)
        set_dic['Pred1RM'].append(round(bv_utils.epley(weight,reps)))
        set_dic['1RM'].append(self.exercise.est1RM)
        set_dic['Int'].append(intensity)
        set_dic['h'].append(h)
        set_dic['Load'].append(load)
        set_dic['phi'].append(load*h)
        if note: set_dic['Notes'].append(note)
        else: set_dic['Notes'].append('')
        self.sets = pd.concat((self.sets,pd.DataFrame(set_dic)),ignore_index=True)
        self.summary = pd.concat((self.summary,pd.DataFrame(set_dic)),ignore_index=True)
        self.exercise.exercise_history = self.sets[self.sets['ID'] == self.exercise.ID]
        self.exercise.est1RM = max(list(self.exercise.exercise_history['Pred1RM']))
        self.exercise.est1RL = max(list(self.exercise.exercise_history['Pred1RL']))
        self.summary.to_csv('../data/.swap.csv',index=False)

# if __name__ == '__main__':
#     bv_utils.list_exercises(sys.argv[1].upper())



from setuptools import find_packages, setup
import pathlib

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / "README.md").read_text(encoding="utf-8")

setup(
    name='biovector',
    packages=find_packages(where='src'),
    version='0.0.0',
    description='Scientific work out app',
    author='Matias Ceau',
    author_email="matias@ceau.net",
    long_description=long_description,
    long_description_content_type="text/markdown",
    include_package_data=True,
    license='GPLv3',
    url="https://github.com/matias-ceau/biovector",
    install_requires=['numpy','scipy','pandas','pyyaml','datetime','seaborn','matplotlib'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: Unix",
        "Topic :: Scientific/Engineering",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Developers"
    ],
    test_suite='tests',
    package_dir={'': 'src'}
)



# -*- coding: utf-8 -*-
"""
Created on Wed Apr 13 13:15:40 2022

@author: mceau
"""
from tabulate import tabulate
import bv_utils
import datetime
import pandas as pd, numpy as np

# weights = pd.read_csv('../data/measures/weight.csv')
sets = bv_utils.Biovector(selected=['sets']).sets
# exercises = pd.read_csv('../data/exercises.csv')

workout = sets[sets['Number'] == 1000]
# wex = set(workout['ID'].values)
# wexn = set(workout['Exercise Name'].values)
# #wexd = {i : {k:v for k,v in zip(exercises.columns,exercises[exercises['ID']==i].to_numpy()[0])} for i in wex}
# name = workout['Workout Name'].values[0]
# number = workout['Number'].values[0]
# program = workout['Program'].values[0]
# wbe = [workout[workout['ID']==i][["Exercise Name","Weight","Reps","Pred1RL","1RL","Pred1RM","1RM","Int","h"]] for i in wex]

# print(name,number,program)
# for n,i in enumerate(wexn):
#     print(tabulate(wbe[n],headers=['W','R','pL','L','pM','M','I','h'],
#                    showindex=True,tablefmt="pretty"))

def print_summary(df):
    startingtime = datetime.datetime.fromtimestamp(df['Timestamp'].values[0])
    name = df['Workout Name'].values[0]
    number = df['Number'].values[0]
    program = df['Program'].values[0]
    start = str(df['Time'].values[0])
    duration = str(datetime.datetime.now() - startingtime)[:-7]
    Phi = int(sum(list(df['phi'])))
    H = round(sum(list(df['h'])),1)
    print('*'*70,'\n')
    print(f"{name:^20}\n{number:^20}\n{program:^20}\n{start:^20}\n{duration:^20}\n{str(Phi)+' kg-m':^20}\n{str(H)+' hard sets':^20}")
    print('{:^20}{:<7}{:<3} {:<4} {:<4}  {:<4} {:<5} {:<2}'.format('', 'W', 'R', '1RM', 'Best', '1RL', 'I', 'h'))
    for i in df.index:
        exo, reps, weight, rm, predrm, predrl, its, h = df.loc[i,'Exercise Name'], df.loc[i,'Reps'], df.loc[i,'Weight'], df.loc[i,'1RM'], df.loc[i,'Pred1RM'], df.loc[i,'Pred1RL'], df.loc[i,'Int'], df.loc[i,'h']
        print(f"{exo:^20}{int(weight):<7}{int(reps):<3} {int(predrm):<4} {int(rm):<4}  {int(predrl):<4} {its:<4.0%} {h:<2}")
    print('*'*70)

if __name__=='__main__':
    #print(workout.columns)
    print_summary(workout)
